@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright (C) 2002-2004 Free Software Foundation, Inc.
+# Copyright (C) 2002-2005 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1584,6 +1584,7 @@ func_all_modules ()
   func_begin_table
   func_module argmatch
   func_module version-etc
+  func_module version-etc-fsf
   func_module long-options
   func_end_table
 
@@ -1605,6 +1606,7 @@ func_all_modules ()
   func_echo "$element"
 
   func_begin_table
+  func_module base64
   func_module diacrit
   func_module getline
   func_module getnline
@@ -1633,6 +1635,16 @@ func_all_modules ()
   func_module restrict
   func_end_table
 
+  element="Sizes of integer types <limits.h>"
+  element=`printf "%s" "$element" | sed -e "$sed_lt" -e "$sed_gt"`
+  func_section_wrap isoc_sup_limits
+  func_wrap H3
+  func_echo "$element"
+
+  func_begin_table
+  func_module ullong_max
+  func_end_table
+
   element="Boolean type and values <stdbool.h>"
   element=`printf "%s" "$element" | sed -e "$sed_lt" -e "$sed_gt"`
   func_section_wrap isoc_sup_stdbool
@@ -1730,6 +1742,7 @@ func_all_modules ()
   func_module chown
   func_module dup2
   func_module ftruncate
+  func_module getaddrinfo
   func_module getcwd
   func_module getgroups
   func_module gethostname
@@ -1748,6 +1761,7 @@ func_all_modules ()
   func_module regex
   func_module rename
   func_module rmdir
+  func_module strtok_r
   func_module utime
   func_end_table
 
@@ -1919,7 +1933,7 @@ func_all_modules ()
   func_module wait-process
   func_module execute
   func_module pipe
-  #func_module sh-quote
+  func_module sh-quote
   func_end_table
 
   element="Java"
@@ -1928,12 +1942,12 @@ func_all_modules ()
   func_wrap H3
   func_echo "$element"
 
-  #func_begin_table
-  #func_module classpath
-  #func_module javacomp
-  #func_module javaexec
+  func_begin_table
+  func_module classpath
+  func_module javacomp
+  func_module javaexec
   #func_module gcj
-  #func_end_table
+  func_end_table
 
   element="Misc"
   element=`printf "%s" "$element" | sed -e "$sed_lt" -e "$sed_gt"`
