@@ -1,9 +1,9 @@
-# $Id: srclistvars.sh,v 1.20 2004/10/11 05:02:17 eggert Exp $
+# $Id: srclistvars.sh,v 1.22 2004/12/12 14:39:22 karl Exp $
 # Variables for srclist-update and srclist.txt.
 # Will change for each user.
 
 case $LOGNAME in
-eggert)
+jas | eggert)
   : ${AUTOCONF=../autoconf}
   : ${AUTOMAKE=../automake}
   : ${GETTEXT=../gettext}
@@ -31,7 +31,7 @@ karl)
   : ${LIBCSRC=$HOME/gnu/src/libc}
   : ${LIBTOOL=$HOME/gnu/src/libtool}
   : ${TEXINFOSRC=/u/texinfo/src}
-  : ${TEXMFROOT=/usr/local/texmf/texmf}
+  : ${TEXMFROOT=/usr/local/texmf/texmf-dist}
   ;;
 
 esac
